aboutsummaryrefslogtreecommitdiff
path: root/lib/VMCore/BasicBlock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/VMCore/BasicBlock.cpp')
-rw-r--r--lib/VMCore/BasicBlock.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/VMCore/BasicBlock.cpp b/lib/VMCore/BasicBlock.cpp
index 40962ef0f3..861aea43c2 100644
--- a/lib/VMCore/BasicBlock.cpp
+++ b/lib/VMCore/BasicBlock.cpp
@@ -70,14 +70,14 @@ void BasicBlock::dropAllReferences() {
std::mem_fun(&Instruction::dropAllReferences));
}
// hasConstantPoolReferences() - This predicate is true if there is a
// reference to this basic block in the constant pool for this method. For
// example, if a block is reached through a switch table, that table resides
// in the constant pool, and the basic block is reference from it.
//
-bool BasicBlock::hasConstantPoolReferences() const {
+bool BasicBlock::hasConstantReferences() const {
for (use_const_iterator I = use_begin(), E = use_end(); I != E; ++I)
- if (::isa<ConstPoolVal>(*I))
+ if (::isa<Constant>(*I))
return true;
return false;
@@ -70,14 +70,14 @@ void BasicBlock::dropAllReferences() {
std::mem_fun(&Instruction::dropAllReferences));
}
-// hasConstantPoolReferences() - This predicate is true if there is a
+// hasConstantReferences() - This predicate is true if there is a
// reference to this basic block in the constant pool for this method. For
// example, if a block is reached through a switch table, that table resides